#pragma once

#include "NPCommonUI.h"
#include "AbstractModel.h"
#include "AbstractControl.h"
#include "RootWindow.h"

class NPCOMMONUI_API AbstractView
{
public:
	AbstractView(void);
	virtual ~AbstractView(void);

	/**
	* @brief	initialize
	*/
	virtual void Init() = 0;
	/**
	* @brief	uninitialize
	*/
	virtual void Close() = 0;
	/**
	* @brief	set model pointer
	* @param	pModel	pointer of model
	* @return	none
	*/
	void	SetModel(AbstractModel* model);
	/**
	* @brief	retrieve model base
	* @return	if function succeeds, the return value is AbstractModel pointer
	*/
	AbstractModel*	GetModel() { return m_Model; }
	/**
	* @brief 	set control pointer
	* @param	pControl pointer of control
	* @return	none
	*/
	void	SetControl(AbstractControl* control);
	/**
	* @brief 	retrieve control base
	* @return	if function succeeds, the return value is AbstractControl pointer
	*/
	AbstractControl*	GetControl() { return m_Control; }

	CRootWindow* GetMainWindow() { return m_RootWindow ; }
	void SetMainWindow(CRootWindow* mainWindow);

private:
	///< Model base
	AbstractModel* m_Model;
	/// Control base
	AbstractControl* m_Control;	
	//main window handle
	CRootWindow* m_RootWindow;
};
